/****************************************************************************

    t6963c.h
    --------

	header file for t6963c.c

    Author:		Jens Renner
    Date:    	2004-01-04
	Updated:	2004-01-05
    Software: 	AVR-GCC

****************************************************************************/


/****************************************************************************
	Definitions
****************************************************************************/

// data port
#define LCD_DATA_OUT PORTC
#define LCD_DATA_IN PINC
#define LCD_DATA_DDR DDRC

// control port
#define LCD_CTRL_OUT PORTA
#define LCD_CTRL_DDR DDRA

// control lines
#define LCD_CTRL_PIN_WR PINA0
#define LCD_CTRL_PIN_RD PINA1
#define LCD_CTRL_PIN_CE PINA2
#define LCD_CTRL_PIN_CD PINA3
#define LCD_CTRL_PIN_RESET PINA4


// display size (240x64 at 6x8 font)
#define LCD_COLS 40
#define LCD_ROWS 8

// display memory
#define LCD_TXTHOME_HI 0x00
#define LCD_TXTHOME_LO 0x00
#define LCD_GFXHOME_HI 0x02
#define LCD_GFXHOME_LO 0x00

// display commands
#define LCD_CMD_SETADDRPTR 0x24
#define LCD_CMD_SETTXTHOME 0x40
#define LCD_CMD_SETTXTAREA 0x41
#define LCD_CMD_SETGFXHOME 0x42
#define LCD_CMD_SETGFXAREA 0x43
#define LCD_CMD_SENDDATAINC 0xc0

// | 1 | 0 | 0 | 0 |CG |MD2|MD1|MD0|  MD: 100 (text attr.); 010 (AND); 001 (XOR); 000 (OR)
#define LCD_CMD_SETMODE 0x80 // 0b10000000

// | 1 | 0 | 0 | 1 |GFX|TXT|CUR|BLK|  text attr.: GFX = 1 & TXT = 1
#define LCD_CMD_SETDISPLAYMODE 0x90 // 0b10010000
#define LCD_CMD_SETDISPLAYMODE_BLK 0x01 // 0b00000001 // bit 0
#define LCD_CMD_SETDISPLAYMODE_CUR 0x02 // 0b00000010 // bit 1
#define LCD_CMD_SETDISPLAYMODE_TXT 0x04 // 0b00000100 // bit 2
#define LCD_CMD_SETDISPLAYMODE_GFX 0x08 // 0b00001000 // bit 3



/****************************************************************************
	Prototypes
****************************************************************************/

int lcd_readstatus (void);
void lcd_wait (void);
void lcd_write(uint8_t data);
void lcd_command(uint8_t cmd);
void lcd_txtdata(uint8_t chr);
void lcd_gfxdata(uint8_t pixel);
void lcd_settxtmode(void);
void lcd_clrtxtmode(void);
void lcd_setgfxmode(void);
void lcd_clrgfxmode(void);
void lcd_delay100ms(void);
void lcd_cleartxt(void);
void lcd_cleargfx(void);
void lcd_init (void);
